;; Generated package description from brief.el  -*- no-byte-compile: t -*-
(define-package "brief" "5.87.0.20201129.234903" "Brief Editor Emulator (Brief Mode)" 'nil :url "https://elpa.gnu.org/packages/brief.html" :keywords '("brief" "emulations" "crisp") :authors '(("Luke Lee" . "luke.yx.lee@gmail.com")) :maintainer '("Luke Lee" . "luke.yx.lee@gmail.com"))
